<?php

namespace Drupal\views_extender_eca\Service;

/**
 * The Memory State for Views Extender ECA.
 *
 * @package Drupal\views_extender_eca\Service
 */
class MemoryState {

  /**
   * Registry storage.
   */
  static private array $registry = [];

  /**
   * Register a new variable.
   *
   * @param string $key
   *   The key.
   * @param mixed $value
   *   The value.
   * @param bool $override
   *   The override flag.
   */
  public static function register(string $key, mixed $value, bool $override = TRUE) {
    if (isset(self::$registry[$key])) {
      if (!$override) {
        return;
      }
    }
    self::$registry[$key] = $value;
  }

  /**
   * Unregister a variable from register by key.
   *
   * @param string $key
   *   The key.
   */
  public static function unregister(string $key) {
    if (isset(self::$registry[$key])) {
      if (is_object(self::$registry[$key]) && (method_exists(self::$registry[$key], '__destruct'))) {
        self::$registry[$key]->__destruct();
      }
      unset(self::$registry[$key]);
    }
  }

  /**
   * Retrieve a value from registry by a key.
   *
   * @param string $key
   *   The key.
   *
   * @return mixed
   *   Register result.
   */
  public static function registry(string $key): mixed {
    if (isset(self::$registry[$key])) {
      return self::$registry[$key];
    }
    return NULL;
  }

}
